Design for Microwave/RF Testing
------------------------------------

When designing a radio-frequency circuit, it is important to consider how to test it. This is particularly important in terms of characterising electronics in relation to multiple photonics loads, and for operation at different frequencies.

Let's review the principles of how to do this. Read further in *On-wafer microwave measurements and de-embedding* by Errikos Lourandakis.

Your specific testing setup will depend on the tools that you have available, and you need to make sure that you are operating it properly. Make sure to follow all calibration procedures accordingly too.

Some common tools for RF/Microwave device characterisations are:

-  A vector network analyser for frequency domain spectrum measurements
-  A radio-frequency bandwidth oscilloscope for time-domain response analysis
-  A radio-frequency bandwidth pulse generator for specific pulse response analysis

You might also be using testing components such as:

-  Coaxial cables
-  On-wafer probes
-  Attenuators and splitters
-  Terminators

You can get similar information from several tools, but some are more suited for other for direct signal measurements rather than indirect time-to-frequency transformations.
